@@ -1,6 +1,6 @@
 import os
 import pytest
-from edalize_common import make_edalize_test
+from .edalize_common import make_edalize_test
 
 
 def run_icestorm_test(tf, pnr_cmdfile="nextpnr-ice40.cmd"):
@@ -57,10 +57,9 @@ def test_icestorm_multiple_pcf(make_edalize_test):
         {"name": "pcf_file.pcf", "file_type": "PCF"},
         {"name": "pcf_file2.pcf", "file_type": "PCF"},
     ]
-    tf = make_edalize_test("icestorm", param_types=[], files=files)
 
     with pytest.raises(RuntimeError) as e:
-        tf.backend.configure()
+        tf = make_edalize_test("icestorm", param_types=[], files=files)
     assert (
         "Nextpnr only supports one PCF file. Found pcf_file.pcf and pcf_file2.pcf"
         in str(e.value)
@@ -72,6 +71,7 @@ def test_icestorm_nextpnr(make_edalize_test):
         "yosys_synth_options": ["some", "yosys_synth_options"],
         "arachne_pnr_options": ["a", "few", "arachne_pnr_options"],
         "nextpnr_options": ["multiple", "nextpnr_options"],
+        "icepack_options": ["several", "icepack_options"],
         "pnr": "next",
     }
     tf = make_edalize_test(
@@ -86,16 +86,15 @@ def test_icestorm_nextpnr(make_edalize_test):
 
 def test_icestorm_invalid_pnr(make_edalize_test):
     name = "test_icestorm_0"
-    tf = make_edalize_test(
-        "icestorm",
-        test_name=name,
-        param_types=["vlogdefine", "vlogparam"],
-        tool_options={"pnr": "invalid"},
-        ref_dir="nextpnr",
-    )
 
     with pytest.raises(RuntimeError) as e:
-        tf.backend.configure()
+        tf = make_edalize_test(
+            "icestorm",
+            test_name=name,
+            param_types=["vlogdefine", "vlogparam"],
+            tool_options={"pnr": "invalid"},
+            ref_dir="nextpnr",
+        )
     assert (
         "Invalid pnr option 'invalid'. Valid values are 'next' for nextpnr or 'none' to only perform synthesis"
         in str(e.value)
