@@ -6,11 +6,16 @@ from .edalize_common import make_edalize_test, tests_dir
 def test_rivierapro(make_edalize_test):
     tool_options = {
         "vlog_options": ["some", "vlog_options"],
+        "vcom_options": ["have", "number", "of", "vcom_options"],
         "vsim_options": ["a", "few", "vsim_options"],
     }
 
     # FIXME: Add VPI tests
-    tf = make_edalize_test("rivierapro", tool_options=tool_options)
+    tf = make_edalize_test(
+        "rivierapro",
+        tool_options=tool_options,
+        param_types=["plusarg", "vlogdefine", "vlogparam", "generic"],
+    )
     tf.backend.configure()
 
     tf.compare_files(
